@@ -1,5 +1,6 @@
 # main
 from .cerver import *
+from .files import *
 from .version import *
 
-__version__ = "0.6"
+__version__ = "0.6.1"
